<?
   require('data.inc');
   require('util.inc');

   define("ALL_TXT",    "all.txt");
   define("THREE_HTML", "three.html");

   function doFilter($entries, $acceptFunction)
   {
      $newEntries = array();
      
      foreach($entries as $entry)
         if($acceptFunction($entry))
            $newEntries[] = $entry;

      return($newEntries);
   }

   function thirtiesFilter($entry)
   {
      return($entry->mYear >= 1930 && $entry->mYear < 1940);
   }

   function fortiesFilter($entry)
   {
      return($entry->mYear >= 1940 && $entry->mYear < 1950);
   }

   function fiftiesFilter($entry)
   {
      return($entry->mYear >= 1950 && $entry->mYear < 1960);
   }

   function sixtiesFilter($entry)
   {
      return($entry->mYear >= 1960 && $entry->mYear < 1970);
   }

   function seventiesFilter($entry)
   {
      return($entry->mYear >= 1970 && $entry->mYear < 1980);
   }

   function eightiesFilter($entry)
   {
      return($entry->mYear >= 1980 && $entry->mYear < 1990);
   }

   function ninetiesFilter($entry)
   {
      return($entry->mYear >= 1990 && $entry->mYear < 2000);
   }

   function oughtiesFilter($entry)
   {
      return($entry->mYear >= 2000 && $entry->mYear < 2010);
   }

   function twoThousandRatingsFilter($entry)
   {
      return($entry->mNRatings >= 2000);
   }

   function compareRatings($first, $second)
   {
      $v1 = (float)$first->mRating;
      $v2 = (float)$second->mRating;

      return($v1 <= $v2);
   }

   function makeSection($title, $headers, $table, $indent)
   {
      $content = Util::makeTable($headers, $table, $indent);

      $content = <<< EOF
$indent<h3>$title</h3>
$indent<blockquote>
$content
$indent</blockquote>
EOF;

      return($content);
   }

   // ---------------------------------------
   // Script Begins Here
   // ---------------------------------------

   if(!Data::getAll(ALL_TXT, $entries, $errMsg))
      die($errMsg);

   $decadeToCount = array();

   foreach($entries as $entry)
   {
      $decade = substr($entry->mYear, 0, strlen($entry->mYear) - 1) . "0";

      if(strlen($decade) == 4)
      {
         if(!isset($decadeToCount[$decade]))
            $decadeToCount[$decade] = 0;

         $decadeToCount[$decade]++;
      }
   }

   krsort($decadeToCount);

   foreach($decadeToCount as $key => $value)
      $listOne[] = array($key, $value);

   $content = makeSection(
      "Total Titles Per Decade",
      array("Decade", "Count"), $listOne, "  "
   );

   // We only care about titles with at least 2,000 ratings

   $entries = doFilter($entries, "twoThousandRatingsFilter");

   $list = array(
      "thirtiesFilter"  => "1930s",
      "fortiesFilter"   => "1940s",
      "fiftiesFilter"   => "1950s",
      "sixtiesFilter"   => "1960s",
      "seventiesFilter" => "1970s",
      "eightiesFilter"  => "1980s",
      "ninetiesFilter"  => "1990s",
      "oughtiesFilter"  => "2000s"
   );

   foreach($list as $filter => $description)
   {
      $newEntries = doFilter($entries, $filter);

      usort($newEntries, "compareRatings");

      $count = 0;
      $list  = array();

      foreach($newEntries as $entry)
      {
         if(!preg_match("/(Seasons?|Series|Vols?\.)/", $entry->mTitle))
         {
            $list[] = array($entry->mRating, $entry->mNRatings, $entry->mTitle);

            if(++$count == 10)
               break;
         }
      }

      $content .= makeSection(
         "Top $description Movies",
         array("Rating", "Number Of Ratings", "Title"), $list,
         "  "
      );

      $content .= "</blockquote>\n";
   }

   if(($f = @fopen(THREE_HTML, "w")) == false)
      die("Could not open: " . THREE_HTML . "\n");

   fprintf($f, "%s\n", Util::makeHTML("Top Movies", $content));

   fclose($f);

   print("Successfully wrote file: " . THREE_HTML . "\n");
?>
